@@ -217,8 +217,10 @@ c
       if(IntInfArray(ProcessNo).process .eq. 'brems' ) then
 c            for brem, electron has the same label as the incident
          if(aTrack.p.code .eq. kelec ) then
-            aTrack.label = iTrack.label
-            reset = .false.
+            if( aTrack.p.fm.p(4) .lt. iTrack.p.fm.p(4)*0.8) then
+               aTrack.label = iTrack.label
+               reset = .false.
+            endif
          endif
       elseif(IntInfArray(ProcessNo).process .eq. 'knock' .or.
      *         IntInfArray(ProcessNo).process .eq. 'mscat' .or.
