@@ -60,7 +60,8 @@ c              reset position and angle.
          endif
       enddo
 
-      
+
+
  10   continue
       end
 #if defined NEXT486
@@ -577,14 +578,17 @@ c                    table zenith is in cos
             elseif(Rdatafmt .eq. 5) then
 c                 in this case, azm is longitude; zen is latitude or cos(lati)
 c       
-               zen =  atan2( inc.pos.xyz.z, 
-     *                sqrt(inc.pos.xyz.x**2+inc.pos.xyz.y**2) )
+c               zen =  atan2( inc.pos.xyz.z, 
+c     *                sqrt(inc.pos.xyz.x**2+inc.pos.xyz.y**2) )
+               zen =  atan2( inc.pos.xyz.r(3),
+     *                sqrt(inc.pos.xyz.r(1)**2+inc.pos.xyz.r(2)**2) )
                if(ZenValue .eq. 'cos') then
                   zen = cos( zen-pi/2.0d0 )
                else
                   zen = zen*Todeg
                endif
-               azm = atan2(inc.pos.xyz.y, inc.pos.xyz.x)*Todeg
+c               azm = atan2(inc.pos.xyz.y, inc.pos.xyz.x)*Todeg
+               azm = atan2(inc.pos.xyz.r(2), inc.pos.xyz.r(1))*Todeg
             else
                call cerrorMsg('dataformat for cut off invalid',0)
             endif
@@ -600,5 +604,3 @@ c
             endif
          endif
          end
-
-
